.. Feast Spark SDK documentation master file, created by
   sphinx-quickstart on Sun Mar 21 17:00:24 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Feast Spark SDK's documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Client
==================

.. automodule:: feast_spark.client
   :members:
   :undoc-members:
   :show-inheritance: